@@ -1,7 +1,7 @@
-require_relative 'extensions'
+require 'asciidoctor/extensions'
+require_relative 'erd/extension'
 
 Asciidoctor::Extensions.register do
-  require_relative 'erd/extension'
   block Asciidoctor::Diagram::ErdBlockProcessor, :erd
   block_macro Asciidoctor::Diagram::ErdBlockMacroProcessor, :erd
 end
